/* Grid
–––––––––––––––––––––––––––––––––––––––––––––––––– */
.container {
    position: relative;
    width: 100%;
    max-width: 960px;
    margin: 0 auto;
    padding: 0 20px;
    box-sizing: border-box;
}

.column, .columns {
    width: 100%;
    float: left;
    box-sizing: border-box;
}

/* For devices larger than 400px */
@media (min-width: 400px) {
    .container {
        width: 85%;
        padding: 0;
    }
}

/* For devices larger than 550px */
@media (min-width: 550px) {
    .container {
        width: 80%;
    }

    .column,
    .columns {
        margin-left: 0.5%;
    }

    .column:first-child,
    .columns:first-child {
        margin-left: 0;
    }

    .one.column,
    .one.columns {
        width: 8%;
    }

    .two.columns {
        width: 16.25%;
    }

    .three.columns {
        width: 22%;
    }

    .four.columns {
        width: 33%;
    }

    .five.columns {
        width: 39.3333333333%;
    }

    .six.columns {
        width: 49.75%;
    }

    .seven.columns {
        width: 56.6666666667%;
    }

    .eight.columns {
        width: 66.5%;
    }

    .nine.columns {
        width: 74.0%;
    }

    .ten.columns {
        width: 82.6666666667%;
    }

    .eleven.columns {
        width: 91.5%;
    }

    .twelve.columns {
        width: 100%;
        margin-left: 0;
    }

    .one-third.column {
        width: 30.6666666667%;
    }

    .two-thirds.column {
        width: 65.3333333333%;
    }

    .one-half.column {
        width: 48%;
    }

    /* Offsets */
    .offset-by-one.column,
    .offset-by-one.columns {
        margin-left: 8.66666666667%;
    }

    .offset-by-two.column,
    .offset-by-two.columns {
        margin-left: 17.3333333333%;
    }

    .offset-by-three.column,
    .offset-by-three.columns {
        margin-left: 26%;
    }

    .offset-by-four.column,
    .offset-by-four.columns {
        margin-left: 34.6666666667%;
    }

    .offset-by-five.column,
    .offset-by-five.columns {
        margin-left: 43.3333333333%;
    }

    .offset-by-six.column,
    .offset-by-six.columns {
        margin-left: 52%;
    }

    .offset-by-seven.column,
    .offset-by-seven.columns {
        margin-left: 60.6666666667%;
    }

    .offset-by-eight.column,
    .offset-by-eight.columns {
        margin-left: 69.3333333333%;
    }

    .offset-by-nine.column,
    .offset-by-nine.columns {
        margin-left: 78.0%;
    }

    .offset-by-ten.column,
    .offset-by-ten.columns {
        margin-left: 86.6666666667%;
    }

    .offset-by-eleven.column,
    .offset-by-eleven.columns {
        margin-left: 95.3333333333%;
    }

    .offset-by-one-third.column,
    .offset-by-one-third.columns {
        margin-left: 34.6666666667%;
    }

    .offset-by-two-thirds.column,
    .offset-by-two-thirds.columns {
        margin-left: 69.3333333333%;
    }

    .offset-by-one-half.column,
    .offset-by-one-half.columns {
        margin-left: 52%;
    }

}

/* Base Styles
–––––––––––––––––––––––––––––––––––––––––––––––––– */
body {
    line-height: 1.6;
    font-family: sans-serif;
    background-color: #eaeaea;
    font-size: 12px;
}

p {
    text-align: justify;
    padding-bottom: 5px;
}

button {
    display: inline-block;
    height: 38px;
    padding: 0 30px;
    color: #555;
    text-align: center;
    font-size: 11px;
    font-weight: 600;
    line-height: 38px;
    letter-spacing: .1rem;
    text-transform: uppercase;
    text-decoration: none;
    white-space: nowrap;
    background-color: transparent;
    border-radius: 4px;
    border: 1px solid #bbb;
    cursor: pointer;
    box-sizing: border-box;
}

.Select-control {
    color: #b4b4b4;
    border-color: rgba(180, 180, 180, 0.4);
    border-radius: 20px 20px 20px 20px / 50% 50% 50% 50%;
    width: 150px;

}

/* Typography
–––––––––––––––––––––––––––––––––––––––––––––––––– */
h1, h2, h3, h4, h5, h6 {
    margin-top: 20px;
    margin-bottom: 0;
    font-weight: 400;
    padding-top: 15px;
}

h1 {
    font-size: 45px;
    line-height: 1.2;
    margin-bottom: 20px;
}

h2 {
    font-size: 36px;
    line-height: 1.25;
    margin-bottom: 18px;
    margin-top: 18px;
}

h3 {
    font-size: 30px;
    line-height: 1.3;
    margin-bottom: 15px;
    margin-top: 15px;
}

h4 {
    font-size: 26px;
    line-height: 1.35;
    margin-bottom: 12px;
    margin-top: 12px;
}

h5 {
    font-size: 22px;
    line-height: 1.5;
    margin-bottom: 6px;
    margin-top: 6px;
}

h6 {
    font-size: 20px;
    line-height: 1.6;
    margin-bottom: 8px;
    margin-top: 8px;
}

/* Custom App CSS
---------------------------------------*/

.div-left-panel {
    background-color: #f9f9f9;
    padding: 32px;
    min-width: 400px;
    max-width: 600px;
}

.logo {
    width: 60px;
    vertical-align: middle;
    border-style: none;
    padding-right: 10px;
}

.logo-text {
    color: #252930;
    font-size: 30px;
    font-weight: bold;
    vertical-align: middle;
}

.table-info-primary {
    font-size: 14px;
}

.table-info-secondary {
    font-size: 12px;
    font-family: sans-serif;
    margin-left: 15px;
    margin-bottom: 10px;
}

.div-right-panel {
    padding: 0 64px 0 32px;
}

.div-dropdown-layout {
    margin-bottom: 5px;
    display: flex;
    justify-content: flex-end;
}
